DPDK patches and discussions
 help / color / mirror / Atom feed
From: Stephen Hemminger <stephen@networkplumber.org>
To: dev@dpdk.org
Cc: Stephen Hemminger <stephen@networkplumber.org>,
	Luca Boccassi <bluca@debian.org>, Gaetan Rivet <grive@u256.net>
Subject: [dpdk-dev] [PATCH v3 04/10] eal: replace usage of blacklist/whitelist in enum
Date: Fri, 12 Jun 2020 17:00:49 -0700	[thread overview]
Message-ID: <20200613000055.7909-5-stephen@networkplumber.org> (raw)
In-Reply-To: <20200613000055.7909-1-stephen@networkplumber.org>

This patch renames the enum values in the EAL include files.
As a backward compatible temporary migration tool, define
a replacement mapping for old values.

The old names relating to blacklist and whitelist are replaced
by block list and allow list, but applications may be using the
older compatibility macros. To help with conversion to new names
cause a message when the compatibility names are used.

Signed-off-by: Stephen Hemminger <stephen@networkplumber.org>
Acked-by: Luca Boccassi <bluca@debian.org>
Acked-by: Gaetan Rivet <grive@u256.net>
---
 lib/librte_eal/common/eal_common_devargs.c | 14 +++++++-------
 lib/librte_eal/include/rte_bus.h           |  8 ++++++--
 lib/librte_eal/include/rte_dev.h           |  8 ++++++--
 lib/librte_eal/include/rte_devargs.h       |  8 ++++++--
 4 files changed, 25 insertions(+), 13 deletions(-)

diff --git a/lib/librte_eal/include/rte_bus.h b/lib/librte_eal/include/rte_bus.h
index d3034d0edf77..19309ad2ddd7 100644
--- a/lib/librte_eal/include/rte_bus.h
+++ b/lib/librte_eal/include/rte_bus.h
@@ -215,10 +215,14 @@ typedef int (*rte_bus_sigbus_handler_t)(const void *failure_addr);
  */
 enum rte_bus_scan_mode {
 	RTE_BUS_SCAN_UNDEFINED,
-	RTE_BUS_SCAN_WHITELIST,
-	RTE_BUS_SCAN_BLACKLIST,
+	RTE_BUS_SCAN_ALLOWLIST,
+	RTE_BUS_SCAN_BLOCKLIST,
 };
 
+/* Backwards compatibility will be deprecated */
+#define RTE_BUS_SCAN_WHITELIST  RTE_BUS_SCAN_ALLOWLIST
+#define RTE_BUS_SCAN_BLACKLIST	RTE_BUS_SCAN_BLOCKLIST
+
 /**
  * A structure used to configure bus operations.
  */
diff --git a/lib/librte_eal/include/rte_dev.h b/lib/librte_eal/include/rte_dev.h
index c8d985fb5cf9..1208b1e99b05 100644
--- a/lib/librte_eal/include/rte_dev.h
+++ b/lib/librte_eal/include/rte_dev.h
@@ -70,10 +70,14 @@ enum rte_kernel_driver {
  * Device policies.
  */
 enum rte_dev_policy {
-	RTE_DEV_WHITELISTED,
-	RTE_DEV_BLACKLISTED,
+	RTE_DEV_ALLOWED,
+	RTE_DEV_BLOCKED,
 };
 
+/* Backwards compatiablity will be deprecated */
+#define RTE_DEV_WHITELISTED RTE_DEV_ALLOWED
+#define RTE_DEV_BLACKLISTED RTE_DEV_BLOCKED
+
 /**
  * A generic memory resource representation.
  */
diff --git a/lib/librte_eal/include/rte_devargs.h b/lib/librte_eal/include/rte_devargs.h
index 898efa0d667b..e1a4277ff167 100644
--- a/lib/librte_eal/include/rte_devargs.h
+++ b/lib/librte_eal/include/rte_devargs.h
@@ -29,11 +29,15 @@ extern "C" {
  * Type of generic device
  */
 enum rte_devtype {
-	RTE_DEVTYPE_WHITELISTED_PCI,
-	RTE_DEVTYPE_BLACKLISTED_PCI,
+	RTE_DEVTYPE_ALLOWED_PCI,
+	RTE_DEVTYPE_BLOCKED_PCI,
 	RTE_DEVTYPE_VIRTUAL,
 };
 
+/* Backwards compatiablity will be removed later */
+#define RTE_DEVTYPE_WHITELISTED_PCI RTE_DEVTYPE_ALLOWED_PCI
+#define RTE_DEVTYPE_BLACKLISTED_PCI RTE_DEVTYPE_BLOCKED_PCI
+
 /**
  * Structure that stores a device given by the user with its arguments
  *
diff --git a/lib/librte_eal/common/eal_common_devargs.c b/lib/librte_eal/common/eal_common_devargs.c
index 2123773ef840..d0d58358fee1 100644
--- a/lib/librte_eal/common/eal_common_devargs.c
+++ b/lib/librte_eal/common/eal_common_devargs.c
@@ -296,7 +296,7 @@ rte_devargs_insert(struct rte_devargs **da)
 	return 0;
 }
 
 /* store a whitelist parameter for later parsing */
 int
 rte_devargs_add(enum rte_devtype devtype, const char *devargs_str)
 {
@@ -313,13 +313,13 @@ rte_devargs_add(enum rte_devtype devtype, const char *devargs_str)
 		goto fail;
 	devargs->type = devtype;
 	bus = devargs->bus;
-	if (devargs->type == RTE_DEVTYPE_BLACKLISTED_PCI)
-		devargs->policy = RTE_DEV_BLACKLISTED;
+	if (devargs->type == RTE_DEVTYPE_BLOCKED_PCI)
+		devargs->policy = RTE_DEV_BLOCKED;
 	if (bus->conf.scan_mode == RTE_BUS_SCAN_UNDEFINED) {
-		if (devargs->policy == RTE_DEV_WHITELISTED)
-			bus->conf.scan_mode = RTE_BUS_SCAN_WHITELIST;
-		else if (devargs->policy == RTE_DEV_BLACKLISTED)
-			bus->conf.scan_mode = RTE_BUS_SCAN_BLACKLIST;
+		if (devargs->policy == RTE_DEV_ALLOWED)
+			bus->conf.scan_mode = RTE_BUS_SCAN_ALLOWLIST;
+		else if (devargs->policy == RTE_DEV_BLOCKED)
+			bus->conf.scan_mode = RTE_BUS_SCAN_BLOCKLIST;
 	}
 	TAILQ_INSERT_TAIL(&devargs_list, devargs, next);
 	return 0;
@@ -296,7 +296,7 @@ rte_devargs_insert(struct rte_devargs **da)
 }
 
-/* store a whitelist parameter for later parsing */
+/* store in allowed list parameter for later parsing */
 int
 rte_devargs_add(enum rte_devtype devtype, const char *devargs_str)
-- 
2.26.2


  parent reply	other threads:[~2020-06-13  0:01 UTC|newest]

Thread overview: 35+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2020-06-13  0:00 [dpdk-dev] [PATCH v3 00/10] rename blacklist/whitelist to block/allow Stephen Hemminger
2020-06-13  0:00 ` [dpdk-dev] [PATCH v3 01/10] rte_ethdev: change comment to rte_dev_eth_mac_addr_add Stephen Hemminger
2020-06-13  0:00 ` [dpdk-dev] [PATCH v3 02/10] mk: replace reference to blacklist/whitelist Stephen Hemminger
2020-06-13  0:00 ` [dpdk-dev] [PATCH v3 03/10] check_maintainers: change variable names Stephen Hemminger
2020-07-10 17:01   ` Thomas Monjalon
2020-06-13  0:00 ` Stephen Hemminger [this message]
2020-06-13  0:00 ` [dpdk-dev] [PATCH v3 05/10] drivers: replace references to blacklist Stephen Hemminger
2020-06-15  6:32   ` Hemant Agrawal
2020-06-13  0:00 ` [dpdk-dev] [PATCH v3 06/10] eal: replace pci-whitelist/pci-blacklist options Stephen Hemminger
2020-06-13  0:00 ` [dpdk-dev] [PATCH v3 07/10] doc: replace references to blacklist/whitelist Stephen Hemminger
2020-06-13  0:00 ` [dpdk-dev] [PATCH v3 08/10] app/test: use new allowlist and blocklist Stephen Hemminger
2020-06-13  0:00 ` [dpdk-dev] [PATCH v3 09/10] doc: add note about blacklist/whitelist changes Stephen Hemminger
2020-06-13  0:00 ` [dpdk-dev] [PATCH v3 10/10] eal: mark old macros for blacklist/whitelist as deprecated Stephen Hemminger
2020-06-17 12:05 ` [dpdk-dev] [PATCH v3 00/10] rename blacklist/whitelist to block/allow Mcnamara, John
2020-07-10 15:06 ` David Marchand
2020-07-14  4:43   ` Stephen Hemminger
2020-07-14  5:33   ` Stephen Hemminger
2020-07-15 10:01     ` [dpdk-dev] [dpdk-techboard] " Thomas Monjalon
2020-09-22 14:28       ` Stephen Hemminger
2020-09-22 16:16         ` Thomas Monjalon
2020-09-22 16:18           ` Thomas Monjalon
2020-09-22 17:12           ` Stephen Hemminger
2020-07-14  5:39 ` [dpdk-dev] [PATCH v4 00/11] rename blacklist/whitelist to exclude/include Stephen Hemminger
2020-07-14  5:39   ` [dpdk-dev] [PATCH v4 01/11] rte_ethdev: change comment to rte_dev_eth_mac_addr_add Stephen Hemminger
2020-07-14  5:39   ` [dpdk-dev] [PATCH v4 02/11] mk: replace reference to blacklist/whitelist Stephen Hemminger
2020-07-14  5:39   ` [dpdk-dev] [PATCH v4 03/11] check_maintainers: change variable names Stephen Hemminger
2020-07-14  5:39   ` [dpdk-dev] [PATCH v4 04/11] eal: replace usage of blacklist/whitelist in enum Stephen Hemminger
2020-07-14  5:39   ` [dpdk-dev] [PATCH v4 05/11] drivers: replace references to blacklist Stephen Hemminger
2020-07-14  5:39   ` [dpdk-dev] [PATCH v4 06/11] eal: replace pci-whitelist/pci-blacklist options Stephen Hemminger
2020-07-14  5:39   ` [dpdk-dev] [PATCH v4 07/11] doc: replace references to blacklist/whitelist Stephen Hemminger
2020-07-14  5:39   ` [dpdk-dev] [PATCH v4 08/11] app/test: use new allowlist and blocklist Stephen Hemminger
2020-07-14  5:39   ` [dpdk-dev] [PATCH v4 09/11] doc: add note about blacklist/whitelist changes Stephen Hemminger
2020-07-14  5:39   ` [dpdk-dev] [PATCH v4 10/11] eal: mark old macros for blacklist/whitelist as deprecated Stephen Hemminger
2020-07-14  5:39   ` [dpdk-dev] [PATCH v4 11/11] doc: update examples to new config options Stephen Hemminger
2020-07-14  6:05   ` [dpdk-dev] [PATCH v4 00/11] rename blacklist/whitelist to exclude/include Stephen Hemminger

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20200613000055.7909-5-stephen@networkplumber.org \
    --to=stephen@networkplumber.org \
    --cc=bluca@debian.org \
    --cc=dev@dpdk.org \
    --cc=grive@u256.net \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).